#
# spec file for package ansilove
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ansilove
Version:        4.2.0
Release:        1.6
Summary:        ANSI and ASCII art to PNG converter
License:        BSD-2-Clause
Group:          Productivity/Graphics/Other
URL:            https://www.ansilove.org
#Git-Clone:     https://github.com/ansilove/ansilove.git
Source:         https://github.com/ansilove/ansilove/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  libansilove-devel >= 1.4.0

%description
AnsiLove/C is a tool to convert ANSI and artscene-related file formats into
PNG images.

The following formats are supported:
 - .ANS - ANSi (ANSI escape sequences: ANSI X3.64 standard)
 - .PCB - PCBoard Bulletin Board System (BBS) own file format
 - .BIN - Binary format (raw memory copy of text mode video memory)
 - .ADF - Artworx format, supporting custom character sets and palettes
 - .IDF - iCE Draw format, supporting custom character sets and palettes
 - .TND - TundraDraw format, supporting 24-bit color mode
 - .XB  - The eXtended Binary XBin format, supporting custom character
          sets and palettes

%prep
%setup -q
find examples/ -type f -name "*.ans" -exec sed -i 's/\r$//' {} +

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%files
%license LICENSE
%doc AUTHORS ChangeLog README.md
%doc examples/
%{_bindir}/ansilove
%{_mandir}/man1/ansilove.1%{?ext_man}

%changelog
* Mon Jun  5 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 4.2.0
  * Add support for the Spleen 8x16 font (requires libansilove >= 1.4.0)
* Fri Apr  7 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.7
  * Always print processing time on stderr
  * Move manual page to the man directory
* Fri Feb 11 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.6
  * Add a test case for retina output
  * Add a test case for SAUCE output
  * Use CMAKE_C_STANDARD instead of hardcoding compiler flags
  * Stop linking against libm, it's not necessary anymore
* Sat Mar  6 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.5
  * Bugfix release
* Thu Oct 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.4
  * Move read_status variable declaration to the top of the function
  * Check fread() return values in readComments() and add error
    handling
  * Introduce the READ_RECORD function-like macro, for fread error
    handling
  * Use READ_RECORD in readRecord() to add fread() error handling
  * Only call memset() if the malloc call succeeds
  * Check strdup() return value and error out on failed allocation
* Fri Sep 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.3
  * Adjust SAUCE flag output to be binary
  * Add -S flag to use SAUCE info for rendering hints. Users must
    now use -S to get iCE color info. This was previously
    automatically pulled without any extra options.
  * Document the new -S flag, allowing to use SAUCE info for
    render options
  * Add support for seccomp on arm
  * Add missing test for __NR_mmap, the mmap syscall doesn't exist
    on arm
* Sun Jul  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.2
  * Define _GNU_SOURCE in CMakeLists.txt to avoid cluttering source
    files
  * No need to set HAVE_SECCOMP to 1, defining it is enough
  * Remove some unneeded seccomp related includes
  * Validate architectures for seccomp
  * Add seccomp support on i386, tested on glibc and musl
  * Remove extraneous underscore in #if defined check
  * Use __NR_ instead of SYS_ prefix in #if defined checks
* Mon May 25 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.1
  * Various documentation tweaks and improvements
  * Define timespecsub macro in compat.h if it doesn't exists
  * Use CLOCK_REALTIME if CLOCK_MONOTONIC is not available
  * Display processing time on exit.
  * Fix includes and add forward declarations in various source
    files
* Mon Feb 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.0
  * Add a new '-t' flag (type), allowing to specify input file type
    and override file type detection
  * Various documentation tweaks and improvements
* Sun Jan 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0.7
- Use OpenBSD style(9) for function prototypes and declarations
- Replace EXIT_SUCCESS by zero in all SAUCE functions
- Do not use typedef for the sauce struct
- Set icecolors to true if defined in SAUCE record ANSiFlags
- Add test cases for most supported formats
- Sync the description of Retina output capabilities with reality
* Tue Dec 10 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0.6
  * Remove extraneous sauceReadFileName() call, read from existing
    SAUCE record
  * Use strdup() when assigning fileName and fext fallback values
  * Call memset() to set all record struct fields to zero
  * Free SAUCE record and comments once and for all when exiting
    the program
* Tue Nov 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0.5
  * Add ENABLE_SECCOMP build option, to allow building seccomp
    support conditionally
  * Use ${CMAKE_INSTALL_BINDIR} instead of hardcoding 'bin'
* Sun Nov  3 2019 Martin Hauke <mardnh@gmx.de>
- Shorten the description
* Mon Oct 28 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0.4
  * Add initial seccomp support to Ansilove
  * Move pledge and seccomp initialization before ansilove_init()
  * Move conditional includes for 'pledge' and 'strtonum' in compat.h
* Sun Oct 27 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 4.0.3
